==> hlw-core-0.0.2-20251021.104452-156-sources.jar: cn/gtmap/hlw/core/dto/third/cqzdyxx/zscx/BdcZscxThridResultDTO.java <==
package cn.gtmap.hlw.core.dto.third.cqzdyxx.zscx;

import lombok.Data;

import java.util.List;

/**
 * @author <a href="mailto:wangzhiwen@gtmap.cn">wangzhiwen</a>
 * @version 2024/1/5 08:57
 * @description 5.4.11    抵押首次获取产权证信息
 */
@Data
public class BdcZscxThridResultDTO {

    /**
     * 区域代码
     */
    private String qydm;

    /**
     * 区域名称
     */
    private String qymc;

    /**
     * 产权证号
     */
    private String fczh;
    /**
     * 不动产单元号
     */
    private String bdcdyh;
    /**
     * 坐落
     */
    private String zl;
    /**
     * 查封状态
     */
    private String cfzt;
    /**
     * 抵押状态
     */
    private String dyzt;
    /**
     * 证书项目ID
     */
    private String zsxmid;
    /**
     * 证书项目ID
     */
    private String xmid;
    /**
     * 不动产单元编号
     */
    private String bdcdybh;
    /**
     * 证书来源
     */
    private String zsly;
    /**
     * 面积
     */
    private String mj;
    /**
     * 行政区划数字代码
     */
    private String xzqhszdm;
    /**
     * 所在层
     */
    private String szc;
    /**
     * 总层数
     */
    private String zcs;
    /**
     * 登记时间
     */
    private String djsj;
    /**
     * 房屋结构
     */
    private String fwjg;
    /**
     * 房屋结构名称
     */
    private String fwjgmc;
    /**
     * 房屋性质
     */
    private String fwxz;
    /**
     * 房屋性质名称
     */
    private String fwxzmc;
    /**
     * 房屋类型
     */
    private String fwlx;
    /**
     * 房屋类型名称
     */
    private String fwlxmc;
    /**
     * 规划用途
     */
    private String ghyt;
    /**
     * 规划用途名称
     */
    private String ghytmc;
    /**
     * 竣工时间
     */
    private String jgsj;
    /**
     * 附记
     */
    private String fj;
    /**
     * 房间号
     */
    private String fjh;
    /**
     * 栋号
     */
    private String dh;
    /**
     * 登记原因
     */
    private String djyy;
    /**
     * 套内面积
     */
    private String tnmj;
    /**
     * 土地使用权面积
     */
    private String tdsyqmj;
    /**
     * 不动产类型代码
     */
    private String bdclxdm;
    /**
     * 不动产类型名称
     */
    private String bdclxmc;
    /**
     * 实际层
     */
    private String sjc;
    /**
     * 单元号
     */
    private String dyh;
    /**
     * 权籍坐落
     */
    private String qjzl;
    /**
     * 权利类型代码
     */
    private String qllxdm;
    /**
     * 权利类型名称
     */
    private String qllxmc;
    /**
     * 宗地/宗海用途代码
     */
    private String zdytdm;
    /**
     * 宗地/宗海权利性质代码
     */
    private String zdqlxzdm;
    /**
     * 宗地/宗海权利性质代码
     */
    private String zdzhqlxz;
    /**
     * 宗地/宗海用途名称
     */
    private String zdytmc;
    /**
     * 宗地/宗海权利性质名称
     */
    private String zdqlxzmc;
    /**
     * 土地分摊面积
     */
    private String tdftmj;
    /**
     * 土地独用面积
     */
    private String tddymj;
    /**
     * 土地权利起始时间
     */
    private String tdqlqssj;
    /**
     * 土地权利结束时间
     */
    private String tdqljssj;
    /**
     * 权籍关联代码
     */
    private String qjgldm;
    /**
     * 宗地面积
     */
    private String zdmj;

    /**
     * 锁定状态
     */
    private String sdzt;

    /**
     * 权利人信息
     */
    private List<BdcZscxQlrThridResultDTO> qlrList;
    /**
     * 关联土地证信息
     */
    private List<BdcZscxTdxxThridResultDTO> gltdzxx;


}

==> hlw-core-0.0.2-20251208.093710-177-sources.jar: cn/gtmap/hlw/core/dto/third/cqzdyxx/zscx/BdcZscxThridResultDTO.java <==
package cn.gtmap.hlw.core.dto.third.cqzdyxx.zscx;

import cn.gtmap.hlw.core.dto.third.cqxx.CqxxThirdFsssxxDTO;
import lombok.Data;

import java.util.List;

/**
 * @author <a href="mailto:wangzhiwen@gtmap.cn">wangzhiwen</a>
 * @version 2024/1/5 08:57
 * @description 5.4.11    抵押首次获取产权证信息
 */
@Data
public class BdcZscxThridResultDTO {

    /**
     * 区域代码
     */
    private String qydm;

    /**
     * 区域名称
     */
    private String qymc;

    /**
     * 产权证号
     */
    private String fczh;
    /**
     * 不动产单元号
     */
    private String bdcdyh;
    /**
     * 坐落
     */
    private String zl;
    /**
     * 查封状态
     */
    private String cfzt;
    /**
     * 抵押状态
     */
    private String dyzt;
    /**
     * 证书项目ID
     */
    private String zsxmid;
    /**
     * 证书项目ID
     */
    private String xmid;
    /**
     * 不动产单元编号
     */
    private String bdcdybh;
    /**
     * 证书来源
     */
    private String zsly;
    /**
     * 面积
     */
    private String mj;
    /**
     * 行政区划数字代码
     */
    private String xzqhszdm;
    /**
     * 所在层
     */
    private String szc;
    /**
     * 总层数
     */
    private String zcs;
    /**
     * 登记时间
     */
    private String djsj;
    /**
     * 房屋结构
     */
    private String fwjg;
    /**
     * 房屋结构名称
     */
    private String fwjgmc;
    /**
     * 房屋性质
     */
    private String fwxz;
    /**
     * 房屋性质名称
     */
    private String fwxzmc;
    /**
     * 房屋类型
     */
    private String fwlx;
    /**
     * 房屋类型名称
     */
    private String fwlxmc;
    /**
     * 规划用途
     */
    private String ghyt;
    /**
     * 规划用途名称
     */
    private String ghytmc;
    /**
     * 竣工时间
     */
    private String jgsj;
    /**
     * 附记
     */
    private String fj;
    /**
     * 房间号
     */
    private String fjh;
    /**
     * 栋号
     */
    private String dh;
    /**
     * 登记原因
     */
    private String djyy;
    /**
     * 套内面积
     */
    private String tnmj;
    /**
     * 土地使用权面积
     */
    private String tdsyqmj;
    /**
     * 不动产类型代码
     */
    private String bdclxdm;
    /**
     * 不动产类型名称
     */
    private String bdclxmc;
    /**
     * 实际层
     */
    private String sjc;
    /**
     * 单元号
     */
    private String dyh;
    /**
     * 权籍坐落
     */
    private String qjzl;
    /**
     * 权利类型代码
     */
    private String qllxdm;
    /**
     * 权利类型名称
     */
    private String qllxmc;
    /**
     * 宗地/宗海用途代码
     */
    private String zdytdm;
    /**
     * 宗地/宗海权利性质代码
     */
    private String zdqlxzdm;
    /**
     * 宗地/宗海权利性质代码
     */
    private String zdzhqlxz;
    /**
     * 宗地/宗海用途名称
     */
    private String zdytmc;
    /**
     * 宗地/宗海权利性质名称
     */
    private String zdqlxzmc;
    /**
     * 土地分摊面积
     */
    private String tdftmj;
    /**
     * 土地独用面积
     */
    private String tddymj;
    /**
     * 土地权利起始时间
     */
    private String tdqlqssj;
    /**
     * 土地权利结束时间
     */
    private String tdqljssj;
    /**
     * 权籍关联代码
     */
    private String qjgldm;
    /**
     * 宗地面积
     */
    private String zdmj;

    /**
     * 锁定状态
     */
    private String sdzt;

    /**
     * 权利人信息
     */
    private List<BdcZscxQlrThridResultDTO> qlrList;
    /**
     * 关联土地证信息
     */
    private List<BdcZscxTdxxThridResultDTO> gltdzxx;
    /**
     * 附属设施
     */
    private List<CqxxThirdFsssxxDTO> fsssxxList;
}
